@@ -8,11 +8,13 @@ use warnings;
 use Carp;
 
 use Astro::Coord::ECI::Utils qw{ __default_station
-    ARRAY_REF PIOVER2 SECSPERDAY };
+    ARRAY_REF PIOVER2 SECSPERDAY
+    @CARP_NOT
+};
 use Exporter ();
 use POSIX qw{ floor };
 
-our $VERSION = '0.100';
+our $VERSION = '0.101';
 
 our @EXPORT_OK = qw{
     almanac almanac_hash
